{% extends "helpdesk/base.html" %}{% load i18n bootstrap %}

{% block helpdesk_title %}{% trans "Edit Ticket" %}{% endblock %}

{% block helpdesk_body %}
<div class="col-xs-6">
<div class="panel panel-default">

<div class="panel-body"><h2>{% trans "Edit a Ticket" %}</h2>

<p>{% trans "Unless otherwise stated, all fields are required." %} {% trans "Please provide as descriptive a title and description as possible." %}</p>

<p><strong>{% trans "Note" %}:</strong> {% blocktrans %}Editing a ticket does <em>not</em> send an e-mail to the ticket owner or submitter. No new details should be entered, this form should only be used to fix incorrect details or clean up the submission.{% endblocktrans %}</p>

<form method='post' action='./'>
<fieldset>
    {{ form|bootstrap }}
    {% comment %}
        {% for field in form %}
            {% if field.is_hidden %}
                {{ field }}
            {% else %}
                <dt><label for='id_{{ field.name }}'>{{ field.label }}</label>{% if not field.field.required %} <span class='form_optional'>{% trans "(Optional)" %}</span>{% endif %}</dt>
                <dd>{{ field }}</dd>
                {% if field.errors %}<dd class='error'>{{ field.errors }}</dd>{% endif %}
                {% if field.help_text %}<dd class='form_help_text'>{{ field.help_text }}</dd>{% endif %}</label>
            {% endif %}
        {% endfor %}
    </dl>
    {% endcomment %}
    <div class='buttons form-group'>
        <input type='submit' class="btn btn-primary" value='{% trans "Save Changes" %}' />
    </div>
</fieldset>

{% csrf_token %}</form>
    </div>
  </div>
</div>

<script>
$( function() {
	$( "#id_due_date" ).datepicker({dateFormat: 'yy-mm-dd'});
} );
</script>

{% endblock %}
