<html>
    <head>
        <style type='text/css'>
        body {
            background-color: #fff;
            color: #333;
            font: 10pt "Trebuchet MS", Arial, sans-serif;
        }

        h1, h2, h3, h4 {
            font-family: Garamond, Times, serif;
        }
        
        h1 {
            color: #00c;
            font-size: 18pt;
            border-bottom: solid 1px #00c;
        }

        h2 {
            color: #c00;
            font-size: 17pt;
            border-bottom: solid 1px #c00;
        }

        h3 {
            font-size: 14pt;
            border-bottom: solid 1px #ccc;
        }

        h4 {
            font-size: 13pt;
        }

        dl {
            padding-left: 2em;
        }
        </style>
        <title>{% block title %}django-helpdesk Help{% endblock %}</title>
    </head>
    <body>
        <h1>{% block heading %}django-helpdesk Help{% endblock %}</h1>

        {% block content %}{% endblock %}
    </body>
</html>
