{% extends "helpdesk/base.html" %}{% load i18n %}

{% block helpdesk_title %}{% trans "Delete Ticket Dependency" %}{% endblock %}

{% block helpdesk_body %}{% blocktrans %}
<h2>Delete Ticket Dependency</h2>

<p>Are you sure you wish to remove the dependency on this ticket?</p>
{% endblocktrans %}

<p><a href='../../'><button class="btn btn-primary btn-lg">{% trans "Don't Delete" %}</button></a></p>

<form method='post' action='./'>
    <button class="btn btn-danger" type='submit'>{% trans "Yes, I Understand - Delete" %}</button>
{% csrf_token %}</form>
{% endblock %}
